@@ -1,9 +1,9 @@
-import Button
-import questions
+import Button.py
+import questions.py
 import pygame
 import pygame.gfxdraw
 import textwrap
-from player import Player, Coffee, Ruby, Eye
+from player.py import Player, Coffee, Ruby, Eye
 
 class Screen():
     def __init__(self, width, height):
